import { Component, Host, h, Prop, State, Event } from '@stencil/core';
import { ChatHead } from '../dyte-chat/components/ChatHead';
import { sanitizeLink } from '../../utils/string';
import { defaultIconPack } from '../../lib/icons';
import { downloadFile } from '../../utils/file';
import { useLanguage } from '../../lib/lang';
import storeState from '../../lib/store';
/**
 * A component which renders an image message from chat.
 */
export class DyteImageMessage {
  constructor() {
    /** Date object of now, to calculate distance between dates */
    this.now = new Date();
    /** Whether the message is continued by same user */
    this.isContinued = false;
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.status = 'loading';
  }
  render() {
    return (h(Host, null,
      !this.isContinued && (h(ChatHead, { name: this.message.displayName, time: this.message.time, now: this.now })),
      h("div", { class: "body", part: "body" },
        h("div", { class: { image: true, loaded: this.status === 'loaded' } },
          h("img", { src: sanitizeLink(this.message.link), onLoad: () => {
              this.status = 'loaded';
            }, onError: () => {
              this.status = 'errored';
            }, onClick: () => {
              if (this.status === 'loaded') {
                this.stateUpdate.emit({ image: this.message });
                storeState.image = this.message;
              }
            } }),
          this.status === 'loading' && (h("div", { class: "image-spinner", title: this.t('Loading image'), "aria-label": this.t('Loading image') },
            h("dyte-spinner", null))),
          this.status === 'errored' && (h("div", { class: "image-errored", title: this.t('Image not found'), "aria-label": this.t('Image not found') },
            h("dyte-icon", { icon: this.iconPack.image_off }))),
          this.status === 'loaded' && (h("div", { class: "actions" },
            h("dyte-button", { class: "action", variant: "secondary", kind: "icon", onClick: () => {
                this.stateUpdate.emit({ image: this.message });
                storeState.image = this.message;
              } },
              h("dyte-icon", { icon: this.iconPack.full_screen_maximize })),
            h("dyte-button", { class: "action", variant: "secondary", kind: "icon", onClick: () => downloadFile(this.message.link, { fallbackName: 'image' }) },
              h("dyte-icon", { icon: this.iconPack.download }))))))));
  }
  static get is() { return "dyte-image-message"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-image-message.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-image-message.css"]
  }; }
  static get properties() { return {
    "message": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "ImageMessage",
        "resolved": "ImageMessage",
        "references": {
          "ImageMessage": {
            "location": "import",
            "path": "@dytesdk/web-core/types/client/DyteChat"
          }
        }
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Text message object"
      }
    },
    "now": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Date",
        "resolved": "Date",
        "references": {
          "Date": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Date object of now, to calculate distance between dates"
      },
      "defaultValue": "new Date()"
    },
    "isContinued": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether the message is continued by same user"
      },
      "attribute": "is-continued",
      "reflect": true,
      "defaultValue": "false"
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "status": {}
  }; }
  static get events() { return [{
      "method": "stateUpdate",
      "name": "dyteStateUpdate",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emits updated state data"
      },
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      }
    }]; }
}
