import { Component, Host, h, Prop, Element, State, Watch } from '@stencil/core';
import { defaultConfig } from '../../lib/default-ui-config';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
import { Render } from '../../lib/render';
import { formatName, shorten } from '../../utils/string';
/**
 * A grid component which handles screenshares, plugins and participants.
 */
export class DyteMixedGrid {
  constructor() {
    /** Participants */
    this.participants = [];
    /** Pinned Participants */
    this.pinnedParticipants = [];
    /** Screenshare Participants */
    this.screenShareParticipants = [];
    /** Active Plugins */
    this.plugins = [];
    /**
     * Aspect Ratio of participant tile
     *
     * Format: `width:height`
     */
    this.aspectRatio = '16:9';
    /** Gap between participant tiles */
    this.gap = 8;
    /** UI Config */
    this.config = defaultConfig;
    /** Icon Pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
  }
  componentWillLoad() {
    // initialise states
    this.screenShareParticipantsChanged(this.screenShareParticipants);
    this.pluginsChanged(this.plugins);
  }
  screenShareParticipantsChanged(participants = []) {
    if (this.activeTab == null && participants.length > 0) {
      this.activeTab = { type: 'screenshare', participant: participants[0] };
    }
    else {
      this.revalidateActiveTab();
    }
  }
  pluginsChanged(plugins) {
    if (plugins.length > 0) {
      const lastIndex = plugins.length - 1;
      this.activeTab = { type: 'plugin', plugin: plugins[lastIndex] };
    }
    else {
      this.revalidateActiveTab();
    }
  }
  revalidateActiveTab() {
    if (this.activeTab != null) {
      if (this.activeTab.type === 'screenshare') {
        const { participant } = this.activeTab;
        if (!this.screenShareParticipants.some((p) => p.id === participant.id)) {
          this.reassignActiveTab();
        }
      }
      else {
        const { plugin } = this.activeTab;
        if (!this.plugins.some((p) => p.id === plugin.id)) {
          this.reassignActiveTab();
        }
      }
    }
  }
  reassignActiveTab() {
    if (this.screenShareParticipants.length > 0) {
      this.activeTab = { type: 'screenshare', participant: this.screenShareParticipants[0] };
    }
    else if (this.plugins.length > 0) {
      const lastIndex = this.plugins.length - 1;
      this.activeTab = { type: 'plugin', plugin: this.plugins[lastIndex] };
    }
  }
  shouldShowSwitcher() {
    return this.screenShareParticipants.length + this.plugins.length > 1;
  }
  render() {
    const defaults = {
      meeting: this.meeting,
      config: this.config,
      states: this.states,
      size: this.size,
      iconPack: this.iconPack,
      t: this.t,
    };
    return (h(Host, null,
      h("main", { id: "main-view", part: "main-view" },
        this.shouldShowSwitcher() && (h("div", { id: "switcher", key: "switcher" },
          this.screenShareParticipants.map((participant) => {
            var _a, _b, _c;
            const name = formatName(participant.name);
            return (h("dyte-button", { title: `${name}'s Screen Share`, key: participant.id, kind: "icon", class: {
                tab: true,
                active: ((_a = this.activeTab) === null || _a === void 0 ? void 0 : _a.type) === 'screenshare' &&
                  ((_b = this.activeTab) === null || _b === void 0 ? void 0 : _b.participant.id) === participant.id,
              }, onClick: () => (this.activeTab = { type: 'screenshare', participant }) },
              h("div", { class: "center" },
                h("dyte-icon", { icon: this.iconPack.share_screen_person }),
                h("span", { class: "name" }, participant.id === ((_c = this.meeting) === null || _c === void 0 ? void 0 : _c.self.id)
                  ? this.t('You')
                  : shorten(name, 6)))));
          }),
          this.plugins.map((plugin) => {
            var _a, _b;
            return (h("dyte-button", { title: plugin.name, key: plugin.id, kind: "icon", class: {
                tab: true,
                active: ((_a = this.activeTab) === null || _a === void 0 ? void 0 : _a.type) === 'plugin' && ((_b = this.activeTab) === null || _b === void 0 ? void 0 : _b.plugin.id) === plugin.id,
              }, onClick: () => (this.activeTab = { type: 'plugin', plugin }) },
              h("div", { class: "center" },
                h("img", { src: plugin.picture }),
                h("span", { class: "name" }, shorten(plugin.name, 6)))));
          }))),
        h("div", { id: "tabs", key: "tabs" },
          this.screenShareParticipants.map((participant) => {
            var _a, _b;
            return (h(Render, { element: "dyte-screenshare-view", defaults: defaults, props: {
                participant,
                key: participant.id,
                style: {
                  display: ((_a = this.activeTab) === null || _a === void 0 ? void 0 : _a.type) === 'screenshare' &&
                    ((_b = this.activeTab) === null || _b === void 0 ? void 0 : _b.participant.id) === participant.id
                    ? 'flex'
                    : 'none',
                },
              }, childProps: { participant, isScreenShare: true }, deepProps: true }));
          }),
          this.plugins.map((plugin) => {
            var _a, _b;
            return (h(Render, { element: "dyte-plugin-main", defaults: defaults, props: {
                plugin,
                key: plugin.id,
                style: {
                  display: ((_a = this.activeTab) === null || _a === void 0 ? void 0 : _a.type) === 'plugin' && ((_b = this.activeTab) === null || _b === void 0 ? void 0 : _b.plugin.id) === plugin.id
                    ? 'flex'
                    : 'none',
                },
              } }));
          }))),
      h(Render, { element: "dyte-mixed-grid", defaults: defaults, childProps: {
          part: 'participants-grid',
          class: 'aside',
          participants: this.participants,
          pinnedParticipants: this.pinnedParticipants,
          screenShareParticipants: this.screenShareParticipants,
          plugins: this.plugins,
          aspectRatio: this.aspectRatio,
          gap: this.gap,
          size: 'sm',
        }, onlyChildren: true })));
  }
  static get is() { return "dyte-mixed-grid"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-mixed-grid.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-mixed-grid.css"]
  }; }
  static get properties() { return {
    "participants": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Peer[]",
        "resolved": "Peer[]",
        "references": {
          "Peer": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Participants"
      },
      "defaultValue": "[]"
    },
    "pinnedParticipants": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Peer[]",
        "resolved": "Peer[]",
        "references": {
          "Peer": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Pinned Participants"
      },
      "defaultValue": "[]"
    },
    "screenShareParticipants": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Peer[]",
        "resolved": "Peer[]",
        "references": {
          "Peer": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Screenshare Participants"
      },
      "defaultValue": "[]"
    },
    "plugins": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "DytePlugin[]",
        "resolved": "Readonly<DytePlugin>[]",
        "references": {
          "DytePlugin": {
            "location": "import",
            "path": "@dytesdk/web-core"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Active Plugins"
      },
      "defaultValue": "[]"
    },
    "aspectRatio": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Aspect Ratio of participant tile\n\nFormat: `width:height`"
      },
      "attribute": "aspect-ratio",
      "reflect": false,
      "defaultValue": "'16:9'"
    },
    "gap": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Gap between participant tiles"
      },
      "attribute": "gap",
      "reflect": false,
      "defaultValue": "8"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "states": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "States object"
      }
    },
    "config": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "UIConfig",
        "resolved": "UIConfig",
        "references": {
          "UIConfig": {
            "location": "import",
            "path": "../../types/ui-config"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "UI Config"
      },
      "defaultValue": "defaultConfig"
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon Pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "activeTab": {}
  }; }
  static get elementRef() { return "host"; }
  static get watchers() { return [{
      "propName": "screenShareParticipants",
      "methodName": "screenShareParticipantsChanged"
    }, {
      "propName": "plugins",
      "methodName": "pluginsChanged"
    }]; }
}
